=============================
DRI GDAL/OGR Helper Functions
=============================

|version| |build|

Installation
============

To install the DRIGO python module:

.. code-block:: console

    pip install drigo

Dependencies
============

 * `gdal <http://www.gdal.org>`__
 * `numpy <https://www.numpy.org>`__

.. |build| image:: https://travis-ci.org/DRI-WSWUP/drigo.svg?branch=master
   :alt: Build status
   :target: https://travis-ci.org/DRI-WSWUP/drigo
.. |version| image:: https://badge.fury.io/py/drigo.svg
   :alt: Latest version on PyPI
   :target: https://badge.fury.io/py/drigo
